@@ -12,7 +12,7 @@ LIXINGREN_HEADER = {
 
 # MONGODB_LINK = "mongodb://localhost:27017/"
 # MONGODB_LINK = "mongodb://192.168.2.188:27017/"  # 数据库连接指向gen8服务器
-MONGODB_LINK = "mongodb://mongoadmin:secretsecret@mongo:27017/"
+MONGODB_LINK = "mongodb://layewang:toorroot!@mongo:27017/"
 
 MONGODB_DB_JIUQUAN = 'db_jiuquan'
 MONGODB_COL_JQ_FUND_VEST_RAW = 'fund_vest_raw'
